diff mercurial/localrepo.py @ 43167:bca9d1a6c4c5

sidedata: rename the configuration option to `exp-use-side-data` We don't want setup configured to use the final version that would end using the experimental one while using and older version. Differential Revision: https://phab.mercurial-scm.org/D7040
author Pierre-Yves David <pierre-yves.david@octobus.net>
date Thu, 10 Oct 2019 04:34:58 +0200
parents beed7ce61681
children 6ceb3721e203
line wrap: on
line diff
--- a/mercurial/localrepo.py	Thu Oct 10 16:02:47 2019 +0200
+++ b/mercurial/localrepo.py	Thu Oct 10 04:34:58 2019 +0200
@@ -3526,8 +3526,8 @@
         if ui.configbool(b'format', b'sparse-revlog'):
             requirements.add(SPARSEREVLOG_REQUIREMENT)
 
-    # experimental config: format.use-side-data
-    if ui.configbool(b'format', b'use-side-data'):
+    # experimental config: format.exp-use-side-data
+    if ui.configbool(b'format', b'exp-use-side-data'):
         requirements.add(SIDEDATA_REQUIREMENT)
     # experimental config: format.exp-use-copies-side-data-changeset
     if ui.configbool(b'format', b'exp-use-copies-side-data-changeset'):